@@ -53,11 +53,3 @@ def user(db, user_without_profile):
     ).delete()
 
     db.commit()
-
-
-@fixture
-def auth_client(client, user):
-    """authenticated client"""
-    response = client.get(f"/api/dummylogin/{user.username}")
-    assert response.status_code == 200
-    return client
